Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type CertificateExpansion
- type CertificateInterface
- type CertificatesGetter
- type PasswordExpansion
- type PasswordInterface
- type PasswordsGetter
- type RSAKeyExpansion
- type RSAKeyInterface
- type RSAKeysGetter
- type SSHKeyExpansion
- type SSHKeyInterface
- type SSHKeysGetter
- type SecretgenV1alpha1Client
- func (c *SecretgenV1alpha1Client) Certificates(namespace string) CertificateInterface
- func (c *SecretgenV1alpha1Client) Passwords(namespace string) PasswordInterface
- func (c *SecretgenV1alpha1Client) RESTClient() rest.Interface
- func (c *SecretgenV1alpha1Client) RSAKeys(namespace string) RSAKeyInterface
- func (c *SecretgenV1alpha1Client) SSHKeys(namespace string) SSHKeyInterface
- type SecretgenV1alpha1Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CertificateExpansion ¶
type CertificateExpansion interface{}
type CertificateInterface ¶
type CertificateInterface interface {
Create(ctx context.Context, certificate *v1alpha1.Certificate, opts v1.CreateOptions) (*v1alpha1.Certificate, error)
Update(ctx context.Context, certificate *v1alpha1.Certificate, opts v1.UpdateOptions) (*v1alpha1.Certificate, error)
UpdateStatus(ctx context.Context, certificate *v1alpha1.Certificate, opts v1.UpdateOptions) (*v1alpha1.Certificate, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Certificate, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.CertificateList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Certificate, err error)
CertificateExpansion
}
CertificateInterface has methods to work with Certificate resources.
type CertificatesGetter ¶
type CertificatesGetter interface {
Certificates(namespace string) CertificateInterface
}
CertificatesGetter has a method to return a CertificateInterface. A group's client should implement this interface.
type PasswordExpansion ¶
type PasswordExpansion interface{}
type PasswordInterface ¶
type PasswordInterface interface {
Create(ctx context.Context, password *v1alpha1.Password, opts v1.CreateOptions) (*v1alpha1.Password, error)
Update(ctx context.Context, password *v1alpha1.Password, opts v1.UpdateOptions) (*v1alpha1.Password, error)
UpdateStatus(ctx context.Context, password *v1alpha1.Password, opts v1.UpdateOptions) (*v1alpha1.Password, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Password, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.PasswordList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Password, err error)
PasswordExpansion
}
PasswordInterface has methods to work with Password resources.
type PasswordsGetter ¶
type PasswordsGetter interface {
Passwords(namespace string) PasswordInterface
}
PasswordsGetter has a method to return a PasswordInterface. A group's client should implement this interface.
type RSAKeyExpansion ¶
type RSAKeyExpansion interface{}
type RSAKeyInterface ¶
type RSAKeyInterface interface {
Create(ctx context.Context, rSAKey *v1alpha1.RSAKey, opts v1.CreateOptions) (*v1alpha1.RSAKey, error)
Update(ctx context.Context, rSAKey *v1alpha1.RSAKey, opts v1.UpdateOptions) (*v1alpha1.RSAKey, error)
UpdateStatus(ctx context.Context, rSAKey *v1alpha1.RSAKey, opts v1.UpdateOptions) (*v1alpha1.RSAKey, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.RSAKey, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.RSAKeyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.RSAKey, err error)
RSAKeyExpansion
}
RSAKeyInterface has methods to work with RSAKey resources.
type RSAKeysGetter ¶
type RSAKeysGetter interface {
RSAKeys(namespace string) RSAKeyInterface
}
RSAKeysGetter has a method to return a RSAKeyInterface. A group's client should implement this interface.
type SSHKeyExpansion ¶
type SSHKeyExpansion interface{}
type SSHKeyInterface ¶
type SSHKeyInterface interface {
Create(ctx context.Context, sSHKey *v1alpha1.SSHKey, opts v1.CreateOptions) (*v1alpha1.SSHKey, error)
Update(ctx context.Context, sSHKey *v1alpha1.SSHKey, opts v1.UpdateOptions) (*v1alpha1.SSHKey, error)
UpdateStatus(ctx context.Context, sSHKey *v1alpha1.SSHKey, opts v1.UpdateOptions) (*v1alpha1.SSHKey, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.SSHKey, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.SSHKeyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.SSHKey, err error)
SSHKeyExpansion
}
SSHKeyInterface has methods to work with SSHKey resources.
type SSHKeysGetter ¶
type SSHKeysGetter interface {
SSHKeys(namespace string) SSHKeyInterface
}
SSHKeysGetter has a method to return a SSHKeyInterface. A group's client should implement this interface.
type SecretgenV1alpha1Client ¶
type SecretgenV1alpha1Client struct {
// contains filtered or unexported fields
}
SecretgenV1alpha1Client is used to interact with features provided by the secretgen.k14s.io group.
func New ¶
func New(c rest.Interface) *SecretgenV1alpha1Client
New creates a new SecretgenV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SecretgenV1alpha1Client, error)
NewForConfig creates a new SecretgenV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SecretgenV1alpha1Client
NewForConfigOrDie creates a new SecretgenV1alpha1Client for the given config and panics if there is an error in the config.
func (*SecretgenV1alpha1Client) Certificates ¶
func (c *SecretgenV1alpha1Client) Certificates(namespace string) CertificateInterface
func (*SecretgenV1alpha1Client) Passwords ¶
func (c *SecretgenV1alpha1Client) Passwords(namespace string) PasswordInterface
func (*SecretgenV1alpha1Client) RESTClient ¶
func (c *SecretgenV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*SecretgenV1alpha1Client) RSAKeys ¶
func (c *SecretgenV1alpha1Client) RSAKeys(namespace string) RSAKeyInterface
func (*SecretgenV1alpha1Client) SSHKeys ¶
func (c *SecretgenV1alpha1Client) SSHKeys(namespace string) SSHKeyInterface
type SecretgenV1alpha1Interface ¶
type SecretgenV1alpha1Interface interface {
RESTClient() rest.Interface
CertificatesGetter
PasswordsGetter
RSAKeysGetter
SSHKeysGetter
}