Documentation
¶
Index ¶
- func NewCertificateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredCertificateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredPasswordInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredRSAKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredSSHKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewPasswordInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewRSAKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewSSHKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type CertificateInformer
- type Interface
- type PasswordInformer
- type RSAKeyInformer
- type SSHKeyInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCertificateInformer ¶
func NewCertificateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewCertificateInformer constructs a new informer for Certificate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredCertificateInformer ¶
func NewFilteredCertificateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredCertificateInformer constructs a new informer for Certificate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredPasswordInformer ¶
func NewFilteredPasswordInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredPasswordInformer constructs a new informer for Password type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredRSAKeyInformer ¶
func NewFilteredRSAKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredRSAKeyInformer constructs a new informer for RSAKey type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredSSHKeyInformer ¶
func NewFilteredSSHKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredSSHKeyInformer constructs a new informer for SSHKey type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewPasswordInformer ¶
func NewPasswordInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewPasswordInformer constructs a new informer for Password type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewRSAKeyInformer ¶
func NewRSAKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewRSAKeyInformer constructs a new informer for RSAKey type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewSSHKeyInformer ¶
func NewSSHKeyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewSSHKeyInformer constructs a new informer for SSHKey type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type CertificateInformer ¶
type CertificateInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.CertificateLister
}
CertificateInformer provides access to a shared informer and lister for Certificates.
type Interface ¶
type Interface interface {
// Certificates returns a CertificateInformer.
Certificates() CertificateInformer
// Passwords returns a PasswordInformer.
Passwords() PasswordInformer
// RSAKeys returns a RSAKeyInformer.
RSAKeys() RSAKeyInformer
// SSHKeys returns a SSHKeyInformer.
SSHKeys() SSHKeyInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type PasswordInformer ¶
type PasswordInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.PasswordLister
}
PasswordInformer provides access to a shared informer and lister for Passwords.
type RSAKeyInformer ¶
type RSAKeyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.RSAKeyLister
}
RSAKeyInformer provides access to a shared informer and lister for RSAKeys.
type SSHKeyInformer ¶
type SSHKeyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.SSHKeyLister
}
SSHKeyInformer provides access to a shared informer and lister for SSHKeys.