Documentation
¶
Index ¶
- type CertificateLister
- type CertificateListerExpansion
- type CertificateNamespaceLister
- type CertificateNamespaceListerExpansion
- type PasswordLister
- type PasswordListerExpansion
- type PasswordNamespaceLister
- type PasswordNamespaceListerExpansion
- type RSAKeyLister
- type RSAKeyListerExpansion
- type RSAKeyNamespaceLister
- type RSAKeyNamespaceListerExpansion
- type SSHKeyLister
- type SSHKeyListerExpansion
- type SSHKeyNamespaceLister
- type SSHKeyNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CertificateLister ¶
type CertificateLister interface {
// List lists all Certificates in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Certificate, err error)
// Certificates returns an object that can list and get Certificates.
Certificates(namespace string) CertificateNamespaceLister
CertificateListerExpansion
}
CertificateLister helps list Certificates. All objects returned here must be treated as read-only.
func NewCertificateLister ¶
func NewCertificateLister(indexer cache.Indexer) CertificateLister
NewCertificateLister returns a new CertificateLister.
type CertificateListerExpansion ¶
type CertificateListerExpansion interface{}
CertificateListerExpansion allows custom methods to be added to CertificateLister.
type CertificateNamespaceLister ¶
type CertificateNamespaceLister interface {
// List lists all Certificates in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Certificate, err error)
// Get retrieves the Certificate from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Certificate, error)
CertificateNamespaceListerExpansion
}
CertificateNamespaceLister helps list and get Certificates. All objects returned here must be treated as read-only.
type CertificateNamespaceListerExpansion ¶
type CertificateNamespaceListerExpansion interface{}
CertificateNamespaceListerExpansion allows custom methods to be added to CertificateNamespaceLister.
type PasswordLister ¶
type PasswordLister interface {
// List lists all Passwords in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Password, err error)
// Passwords returns an object that can list and get Passwords.
Passwords(namespace string) PasswordNamespaceLister
PasswordListerExpansion
}
PasswordLister helps list Passwords. All objects returned here must be treated as read-only.
func NewPasswordLister ¶
func NewPasswordLister(indexer cache.Indexer) PasswordLister
NewPasswordLister returns a new PasswordLister.
type PasswordListerExpansion ¶
type PasswordListerExpansion interface{}
PasswordListerExpansion allows custom methods to be added to PasswordLister.
type PasswordNamespaceLister ¶
type PasswordNamespaceLister interface {
// List lists all Passwords in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Password, err error)
// Get retrieves the Password from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Password, error)
PasswordNamespaceListerExpansion
}
PasswordNamespaceLister helps list and get Passwords. All objects returned here must be treated as read-only.
type PasswordNamespaceListerExpansion ¶
type PasswordNamespaceListerExpansion interface{}
PasswordNamespaceListerExpansion allows custom methods to be added to PasswordNamespaceLister.
type RSAKeyLister ¶
type RSAKeyLister interface {
// List lists all RSAKeys in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.RSAKey, err error)
// RSAKeys returns an object that can list and get RSAKeys.
RSAKeys(namespace string) RSAKeyNamespaceLister
RSAKeyListerExpansion
}
RSAKeyLister helps list RSAKeys. All objects returned here must be treated as read-only.
func NewRSAKeyLister ¶
func NewRSAKeyLister(indexer cache.Indexer) RSAKeyLister
NewRSAKeyLister returns a new RSAKeyLister.
type RSAKeyListerExpansion ¶
type RSAKeyListerExpansion interface{}
RSAKeyListerExpansion allows custom methods to be added to RSAKeyLister.
type RSAKeyNamespaceLister ¶
type RSAKeyNamespaceLister interface {
// List lists all RSAKeys in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.RSAKey, err error)
// Get retrieves the RSAKey from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.RSAKey, error)
RSAKeyNamespaceListerExpansion
}
RSAKeyNamespaceLister helps list and get RSAKeys. All objects returned here must be treated as read-only.
type RSAKeyNamespaceListerExpansion ¶
type RSAKeyNamespaceListerExpansion interface{}
RSAKeyNamespaceListerExpansion allows custom methods to be added to RSAKeyNamespaceLister.
type SSHKeyLister ¶
type SSHKeyLister interface {
// List lists all SSHKeys in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.SSHKey, err error)
// SSHKeys returns an object that can list and get SSHKeys.
SSHKeys(namespace string) SSHKeyNamespaceLister
SSHKeyListerExpansion
}
SSHKeyLister helps list SSHKeys. All objects returned here must be treated as read-only.
func NewSSHKeyLister ¶
func NewSSHKeyLister(indexer cache.Indexer) SSHKeyLister
NewSSHKeyLister returns a new SSHKeyLister.
type SSHKeyListerExpansion ¶
type SSHKeyListerExpansion interface{}
SSHKeyListerExpansion allows custom methods to be added to SSHKeyLister.
type SSHKeyNamespaceLister ¶
type SSHKeyNamespaceLister interface {
// List lists all SSHKeys in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.SSHKey, err error)
// Get retrieves the SSHKey from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.SSHKey, error)
SSHKeyNamespaceListerExpansion
}
SSHKeyNamespaceLister helps list and get SSHKeys. All objects returned here must be treated as read-only.
type SSHKeyNamespaceListerExpansion ¶
type SSHKeyNamespaceListerExpansion interface{}
SSHKeyNamespaceListerExpansion allows custom methods to be added to SSHKeyNamespaceLister.